"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateArguments = void 0;
var chalk_1 = __importDefault(require("chalk"));
var helpers_1 = require("yargs/helpers");
var yargs_1 = __importDefault(require("yargs/yargs"));
var validateArguments = function () {
    var argv = (0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
        .scriptName('gqlCodegen')
        .usage(chalk_1.default.blueBright('$0 -s [schemaUrl] -f [fetcherHookPath] -o [outputPath]'))
        .epilogue('Generates types and react-query hooks from a graphql schema')
        .example('$0 -s http://localhost:3333/graphql -o ./src/api -f ./useFetcher#useFetcher', '')
        .describe('s', chalk_1.default.cyanBright('Graphql schema url'))
        .describe('o', chalk_1.default.cyanBright('Generated code output path'))
        .describe('f', chalk_1.default.cyanBright('Fetcher hook path and name (<path>#<hookName>)'))
        .check(function (args) {
        var urlRegex = /^(https?|chrome):\/\/[^\s$.?#].[^\s]*$/;
        if (!urlRegex.test(args.s)) {
            throw new Error(chalk_1.default.bold.redBright('Errors:\n-s\t\tExpecting an url\n'));
        }
        return true;
    })
        .demandOption(['s', 'o', 'f']).argv;
    return {
        schemaUrl: argv.s,
        outputPath: argv.o,
        fetcherPath: argv.f,
    };
};
exports.validateArguments = validateArguments;
